@@ -11,15 +11,18 @@ import weakref
 
 from clu.constants.consts import DEBUG, NoDefault
 from clu.constants.polyfills import Path
-from clu.config.base import NAMESPACE_SEP
-from clu.fs.misc import stringify, wrap_value
+from clu.abstract import Slotted
+from clu.config.abc import NAMESPACE_SEP, FlatOrderedSet
 from clu.naming import nameof
 from clu.predicates import (negate, isclasstype,
-                            getpyattr, always, no_op,
-                            uncallable, isexpandable, iscontainer,
-                            tuplize, slots_for)
-from clu.typology import ismapping, isnumber, isstring, ispath, isvalidpath
-from clu.exporting import Slotted, Exporter
+                            getpyattr, always, no_op, attr,
+                            uncallable, hoist, tuplize, slots_for,
+                            isnotnone)
+from clu.repr import stringify
+from clu.typology import (isderivative, ismapping,
+                                        isnumber,
+                                        isstring, ispath, isvalidpath)
+from clu.exporting import Exporter
 
 exporter = Exporter(path=__file__)
 export = exporter.decorator()
@@ -29,89 +32,6 @@ class ValidationError(Exception):
     """ An error occuring during field validation or configuration. """
     pass
 
-hoist = lambda thing: uncallable(thing) and wrap_value(thing) or thing
-
-@export
-class FlatOrderedSet(collections.abc.Set,
-                     collections.abc.Sequence,
-                     collections.abc.Hashable,
-                     metaclass=Slotted):
-    
-    """ FlatOrderedSet is a structure designed to coalesce any nested
-        elements with which it is initialized into a flat, ordered sequence
-        devoid of None-values. It has both set and sequence properties –
-        membership can be tested as with a set; comparisons can be made with
-        less-than and greater-than operators, as with a set; recombinant 
-        operations are performed with binary-and and binary-or operators, as
-        with a set – but like a sequence, iterating a FlatOrderedSet has a
-        stable and deterministic order and items may be retrieved from an
-        instance using subscript indexes (e.g. flat_ordered_set[3]). 
-        
-        Here’s an example of the coalescing behavior:
-        
-            stuff = FlatOrderedSet(None, "a", "b", FlatOrderedSet("c", None, "a", "d"))
-            summary = FlatOrderedSet("a", "b", "c", "d")
-            
-            assert stuff == summary
-        
-        One can optionally specify, as a keyword-only argument, a unary boolean
-        function “predicate” that will be used to filter out any of the items
-        used to initialize the FlatOrderedSet for which the predicate returns
-        a Falsey value. 
-    """
-    
-    __slots__ = tuplize('things')
-    
-    def __init__(self, *things, predicate=always):
-        """ Initialize a new FlatOrderedSet instance with zero or more things.
-            
-            Optionally, a unary boolean function “predicate” may be specified
-            to filter the list of things.
-        """
-        if uncallable(predicate):
-            raise ValueError("FlatOrderedSet requires a callable predicate")
-        thinglist = []
-        if len(things) == 1:
-            if isexpandable(things[0]):
-                things = things[0]
-            elif iscontainer(things[0]):
-                things = tuple(things[0])
-        for thing in things:
-            if thing is not None:
-                if isinstance(thing, type(self)):
-                    for other in thing.things:
-                        if predicate(other):
-                            if other not in thinglist:
-                                thinglist.append(other)
-                elif predicate(thing):
-                    if thing not in thinglist:
-                        thinglist.append(thing)
-        self.things = tuple(thinglist)
-    
-    def __iter__(self):
-        return iter(self.things)
-    
-    def __len__(self):
-        return len(self.things)
-    
-    def __contains__(self, thing):
-        return thing in self.things
-    
-    def __getitem__(self, idx):
-        return self.things[idx]
-    
-    def __bool__(self):
-        return len(self.things) > 0
-    
-    def __hash__(self):
-        return hash(self.things) & hash(id(self.things))
-    
-    def __repr__(self):
-        cnm = nameof(type(self))
-        lst = repr(self.things)
-        hxa = hex(id(self))
-        return f"{cnm}({lst}) @ {hxa}"
-
 @export
 class functional_and(FlatOrderedSet,
                      collections.abc.Callable):
@@ -135,7 +55,7 @@ class functional_and(FlatOrderedSet,
             otherwise, False is returned.
         """
         return all(function(thing) \
-               for function in reversed(self.things) \
+               for function in reversed(self) \
                 if function is not None)
 
 @export
@@ -162,7 +82,7 @@ class functional_set(FlatOrderedSet,
             each function in turn, and finally returning the last return value
             once the sequence of functions has been exhausted.
         """
-        for function in reversed(self.things):
+        for function in reversed(tuple(filter(isnotnone, self))):
             if function is not None:
                 thing = function(thing)
         return thing
@@ -266,9 +186,9 @@ class FieldBase(abc.ABC, metaclass=Slotted):
     def __get__(self, instance, cls=None):
         if instance is None:
             return self
-        return getpyattr(instance, 'fields').get(self.name,
-                                       namespace=self.namespace,
-                                         default=self.default or NoDefault)
+        return getpyattr(instance, 'fields').get(attr(self, 'name', 'namespace'),
+                                            namespace=self.namespace,
+                                              default=self.default or NoDefault)
     
     def __set__(self, instance, value):
         # Check for outlawed Nones:
@@ -300,7 +220,15 @@ class FieldBase(abc.ABC, metaclass=Slotted):
         return self.name
     
     def __repr__(self):
-        return stringify(self, slots_for(type(self)))
+        return stringify(self,
+               slots_for(self),
+               try_callables=False)
+    
+    def __json__(self, **kwargs):
+        instance = kwargs.get('instance')
+        return self.__get__(instance, cls=None)
+
+predicate_for = lambda cls: lambda thing: isderivative(thing, cls)
 
 @export
 class SchemaField(FieldBase):
@@ -314,12 +242,11 @@ class SchemaField(FieldBase):
             it’s a Schema-backed fieldset).
         """
         self.cls = cls
-        isthisclass = lambda thing: isinstance(thing, cls)
         super(SchemaField, self).__init__(default=cls,
                                           validator=functional_and(validator,
-                                                                   isthisclass,
+                                                                   predicate_for(cls),
                                                                    isclasstype))
-        
+    
     def __set__(self, instance, value):
         try:
             if ismapping(value):
@@ -580,8 +507,8 @@ class BooleanField(FieldBase):
                                            extractor=functional_set(extractor, bool),
                                            allow_none=False)
 
-isdatetime = lambda thing: isinstance(thing, datetime)
-istimedelta = lambda thing: isinstance(thing, timedelta)
+isdatetime = predicate_for(datetime)
+istimedelta = predicate_for(timedelta)
 
 @export
 class DateTimeField(FieldBase):
@@ -940,7 +867,7 @@ class NamespacedFieldManager(object):
     
     def __iter__(self):
         # TODO: make this iterate over the currently defined field instances:
-        return iter(self.namespace_stack)
+        yield from self.namespace_stack
     
     def __repr__(self):
         return f"<pseudo-module '{self.__module__}.{self.__name__}' from '{self.__file__}' " \
@@ -1044,7 +971,7 @@ def __getattr__(key):
     raise AttributeError(f"module {__name__} has no attribute {key}")
 
 # MODULE EXPORTS:
-export(hoist,           name='hoist',           doc="hoist(thing) → if “thing” isn’t already callable, turn it into a lambda that returns it as a value (using “wrap_value(…)”).")
+export(predicate_for,   name='predicate_for',   doc="predicate_for(cls) → a predicate factory, returning a new predicate function that returns True for instances of “cls”")
 export(isdatetime,      name='isdatetime',      doc="isdatetime(thing) → boolean predicate, True if `thing` is an instance of “datetime.datetime”")
 export(istimedelta,     name='istimedelta',     doc="istimedelta(thing) → boolean predicate, True if `thing` is an instance of “datetime.timedelta”")
 
