@@ -1,9 +1,11 @@
 # -*- coding: utf-8 -*-
 from __future__ import print_function
-from functools import wraps
+from functools import lru_cache, wraps
 from importlib.machinery import all_suffixes
+from pathlib import Path
 
 import abc
+import clu.abstract
 import collections
 import collections.abc
 import inspect
@@ -17,8 +19,6 @@ iterchain = itertools.chain.from_iterable
 
 from clu.constants.consts import λ, φ, BASEPATH, PROJECT_NAME, NoDefault, pytuple # type: ignore
 from clu.constants.exceptions import ExportError, ExportWarning
-from clu.constants.polyfills import lru_cache # type: ignore
-from clu.abstract import Slotted, ValueDescriptor, Prefix
 
 # Q.v. `search_by_id(…)` function sub.
 cache = lambda function: lru_cache(maxsize=128, typed=False)(function)
@@ -140,11 +140,10 @@ def determine_name(thing, name=None, try_repr=False):
     if thing is None:
         return None
     # Check for a function wrapper:
-    if callable(thing):
-        # N.B. when the Walrus hits Python main this’ll be
-        # a good spot for one of those:
-        if callable(getattr(thing, '__wrapped__', None)):
-            return determine_name(thing.__wrapped__)
+    # N.B. when the Walrus hits Python main this’ll be
+    # a good spot for one of those:
+    if callable(getattr(thing, '__wrapped__', None)):
+        return determine_name(thing.__wrapped__)
     # Check for telltale function-object attributes:
     code = None
     if hasattr(thing, '__code__'): # Python 3.x
@@ -235,6 +234,9 @@ replaceable_endings  = tuple(f"{pre}{suf}" \
                                                   ending_suffixes))
 replaceable_endings += ending_suffixes
 
+# Derive the filesystem’s root path representation:
+root_path = Path(BASEPATH).absolute().root
+
 def path_to_dotpath(path, relative_to=None):
     """ Convert a file path (e.g. “/yo/dogg/iheard/youlike.py”)
         to a dotpath (á la “yo.dogg.iheard.youlike”) in what I
@@ -253,8 +255,8 @@ def path_to_dotpath(path, relative_to=None):
     
     # Relativize the path to either the “relative_to” arg
     # …or – if that’s not a thing – the filesystem root,
-    # and replace slashes with dots:
-    relpath = os.path.relpath(path, start=relative_to or "/")
+    # and replace path separators with dots:
+    relpath = os.path.relpath(path, start=relative_to or root_path)
     dotpath = relpath.replace(os.path.sep, QUALIFIER)
     
     # Trim off any remaining “.py” suffixes,
@@ -278,10 +280,11 @@ def path_to_dotpath(path, relative_to=None):
 ismergeable = lambda thing: isinstance(thing, collections.abc.Mapping)
 isstring = lambda thing: isinstance(thing, str)
 
-classes = {}
+# The actual exporter subclass registry datastructures:
+classes = weakref.WeakValueDictionary()
 appnames = set()
 
-class Registry(abc.ABC, metaclass=Slotted):
+class Registry(abc.ABC, metaclass=clu.abstract.Slotted):
     
     """ A class-registry mixin ancestor type suitable for use
         in the ExporterBase inheritance chain – it uses the
@@ -300,7 +303,7 @@ class Registry(abc.ABC, metaclass=Slotted):
         classes[appname] = cls
         super(Registry, cls).__init_subclass__(**kwargs) # type: ignore
         cls.instances = weakref.WeakValueDictionary()
-        cls.appname = ValueDescriptor(appname)
+        cls.appname = clu.abstract.ValueDescriptor(appname)
     
     @staticmethod
     def all_appnames():
@@ -367,7 +370,8 @@ class Registry(abc.ABC, metaclass=Slotted):
         """
         return search_modules(thing, *cls.all_modules())[0]
 
-class ExporterBase(collections.abc.MutableMapping, Registry, metaclass=Prefix):
+class ExporterBase(collections.abc.MutableMapping,
+                   Registry, metaclass=clu.abstract.Prefix):
     
     """ The base class for “clu.exporting.Exporter”. Override this
         class in your own project to use the CLU exporting mechanism –
